@@ -187,6 +187,10 @@ def draw_polygon(img, points, color='blue', width=1, label=None, label_xy=(0, 0)
         xy = [(x1 + x2, y1 + y2) for (x1, y1), (x2, y2) in [(corner, label_xy)]][0]
         draw.text(xy, label, fill=label_color,font=font)
     return img
+def draw_polygons(img, polygons, color='blue', width=1, label=None, label_xy=(0, 0), label_color=None,font=None):
+    for polygon in polygons:
+        img=draw_polygon(img,polygon,color=color,width=width,label=label,label_xy=label_xy,label_color=label_color,font=font)
+    return img
 def draw_textboxes(img,textboxes,copy=False,font_size=32):
     if copy:
         img=img.copy()
